@@ -225,10 +225,16 @@ download.file.custom <- function(url = "", destfile = "", is.dir = FALSE, showWa
 }
 
 # Check destdir and decide wheather overwrite
-destdir.initial <- function(destdir, strict = TRUE, download.only = FALSE, local.source = NULL) {
+destdir.initial <- function(destdir, strict = TRUE, download.only = FALSE, local.source = NULL, 
+  is.git = TRUE, overwrite = FALSE) {
   if (!is.null(local.source)) {
     return(TRUE)
   }
+  if (overwrite && dir.exists(destdir)) {
+    unlink(destdir, recursive = TRUE)
+  } else if (!is.git) {
+    return(TRUE)
+  }
   if (!download.only && file.exists(destdir) && length(list.files(destdir) != 0) && 
     strict) {
     flag <- "y"
